NOCONFIGURE=indeed ./autogen.sh
./configure --with-distro=NovellWin32 --with-lang="af ar bn-IN ca cs da de el en-GB es fi fr gu-IN he hi-IN hu it ja ko mr-IN nb nl nn pl pt-BR pt ru sk sv ta-IN xh zh-CN zh-TW zu" --with-poor-help-localizations="af ar bn-IN ca el en-GB fi gu-IN hi-IN mr-IN nb nn pt sk ta-IN xh zu" --with-dejavu-fonts=2.24 --disable-build-mozilla --enable-minimizer --enable-presenter-console --enable-pdfimport --enable-wiki-publisher --enable-report-builder --with-extension-integration
