NOCONFIGURE=indeed ./autogen.sh
./configure --disable-dependency-tracking --with-num-cpus=2 --with-distro=GoOoMacOSX --with-lang="af ar bn-IN ca cs da de el en-GB es fi fr gu-IN he hi-IN hu it ja ko mr-IN nb nl nn pl pt-BR pt ru sk sv ta-IN xh zh-CN zh-TW zu" --with-poor-help-localizations="af ar bn-IN ca el en-GB fi gu-IN hi-IN mr-IN nb nn pt sk ta-IN xh zu" --disable-mozilla --disable-build-mozilla
